@@ -1,4 +1,4 @@
-/* $Id: common.c,v 1.10 1999/05/11 11:59:29 roca Exp $ */
+/* $Id: common.c,v 1.11 1999/06/23 13:17:03 roca Exp $ */
 /*
  * common.c
  *
@@ -687,7 +687,7 @@ UsageHelp  (char	*proc)
 	PRINT_OUT((stdout, "\nNetwork performance evaluation environment\n"))
 
 	/* Edit version number as appropriate... */
-	PRINT_OUT((stdout, "Version 0.92.4 - vincent.roca@lip6.fr\n\n"))
+	PRINT_OUT((stdout, "Version 0.92.5 - vincent.roca@lip6.fr\n\n"))
 
 	PRINT_OUT((stdout, "%s usage:\n", proc))
 	PRINT_OUT((stdout, "	-help	print this page\n"))
@@ -722,9 +722,9 @@ UsageHelp  (char	*proc)
 	/******/
 	PRINT_OUT((stdout, "  Test parameters:\n"))
 #ifdef CLIENT
-	PRINT_OUT((stdout, "	-h[ost]H set remote host to H (name or address)\n"))
+	PRINT_OUT((stdout, "	-h[ost]H set remote host to H (name or dotted address) to H\n"))
 	PRINT_OUT((stdout, "		(default is ""localhost""/127.0.0.1)\n"))
-	PRINT_OUT((stdout, "	-a[ddr]A set remote [uni/broad/multi]cast (dotted) address to A\n"))
+	PRINT_OUT((stdout, "	-a[ddr]A set remote [uni/broad/multi]cast dotted address to A\n"))
 	PRINT_OUT((stdout, "		(mutually exclusive with -hH)\n"))
 #else /* SERVER */
 	PRINT_OUT((stdout, "	-addrA	set remote [uni/broad/multi]cast address to A\n"))
